@@ -3,19 +3,19 @@ dependencies = ["humanfriendly"]
 
 只能用来移动一个文件夹内的第一层文件，不能移动文件夹，也不会递归处理子文件夹。
 
-本插件用来移动新文件，通过 st_ctime 来对文件排序。
-    st_ctime:
-        the time of most recent metadata change on Unix,
-        the time of creation on Windows, expressed in seconds.
+本插件用来移动新文件，通过 st_mtime 来对文件排序。
+    st_mtime:
+        time of most recent content modification
 
 使用 shutil.move 来移动文件，因此会先尝试改名，改名失败再进行复制和删除操作。
 
 https://github.com/ahui2016/ffe/raw/main/recipes/move-new-files.py
-# version: 2022-01-11
+version: 2022-01-13
 """
 
 # 每个插件都应如上所示在文件开头写简单介绍，以便 "ffe install --peek" 功能窥视插件概要。
 
+from sys import prefix
 from humanfriendly import format_size
 import shutil
 from pathlib import Path
@@ -48,17 +48,20 @@ names = [                 # names 必须是（不多不少）两个文件夹
 [tasks.options]
 n = 1              # 移动多少个最新的文件
 suffix = ".jpg"    # 指定文件名的末尾，空字符串表示不限
+prefix = ""        # 指定文件名的开头，空字符串表示不限
 overwrite = false  # 是否覆盖同名文件
 copy_only = false  # 设为 true 则只是复制，不删除源头文件
 names = []         # 只有当多个任务组合时才使用此项代替命令行输入
 
 # 注意：本插件在设计上并未对移动大量文件的场景进行优化，建议只用来移动少量文件。
-# version: 2022-01-11
+# version: 2022-01-13
 """
 
     @property  # 注意: 必须设为 @property
     def default_options(self) -> dict:
-        return dict(n=1, suffix="", overwrite=False, copy_only=False, names=[])
+        return dict(
+            n=1, suffix="", prefix="", overwrite=False, copy_only=False, names=[]
+        )
 
     def validate(self, names: list[str], options: dict) -> ErrMsg:
         """初步检查参数（比如文件数量与是否存在），并初始化以下项目：
@@ -67,6 +70,7 @@ names = []         # 只有当多个任务组合时才使用此项代替命令
         - self.src_dir
         - self.n
         - self.suffix
+        - self.prefix
         - self.overwrite
         - self.copy_only
         """
@@ -96,6 +100,7 @@ names = []         # 只有当多个任务组合时才使用此项代替命令
             return '"n" should be 1 or larger'
 
         self.suffix = options.get("suffix", "").strip().lower()
+        self.prefix = options.get("prefix", "").strip().lower()
         self.overwrite, err = get_bool(options, "overwrite")
         self.copy_only = options.get("copy_only", False)
         return err
@@ -126,12 +131,18 @@ names = []         # 只有当多个任务组合时才使用此项代替命令
 
     def get_new_files(self) -> tuple[list[Path], int, int]:
         src_files = Path(self.src_dir).glob("*")
-        src_files = [
-            x
-            for x in src_files
-            if x.is_file() and x.__str__().lower().endswith(self.suffix)
-        ]
-        src_files.sort(key=lambda x: x.lstat().st_ctime, reverse=True)
+        src_files = [x for x in src_files if x.is_file()]
+        if self.suffix:
+            print(f"suffix: {self.suffix}")
+            src_files = [
+                x for x in src_files if x.__str__().lower().endswith(self.suffix)
+            ]
+        if self.prefix:
+            src_files = [
+                x for x in src_files if x.name.__str__().lower().startswith(self.prefix)
+            ]
+
+        src_files.sort(key=lambda x: x.lstat().st_mtime, reverse=True)
         src_files = src_files[: self.n]
         files_size = sum([x.lstat().st_size for x in src_files])
         free_space = shutil.disk_usage(self.target_dir).free
@@ -165,7 +176,7 @@ def print_and_move(
             continue
 
         # 此时 dst 必然不存在，正常移动文件即可。
-        verb = "copy" if copy_only else "move"
+        verb = "copy to" if copy_only else "move to"
         print(f"-- {verb} {dst}")
         if really_run:
             copy_or_move(src, dst, copy_only)
