@@ -4,6 +4,7 @@
 采用 lzma 压缩方法，打包压缩后的后缀名是 '.tar.xz'
 
 https://github.com/ahui2016/ffe/raw/main/recipes/tar-xz.py
+version: 2022-01-13
 """
 
 # 每个插件都应如上所示在文件开头写简单介绍，以便 "ffe install --peek" 功能窥视插件概要。
@@ -39,14 +40,16 @@ names = [          # 如果提供 1 个文件，并且后缀是 '.tar.xz',
 ]
 
 [tasks.options]
-output = ""       # 指定压缩后的文件名或解压缩时的目标文件夹，
-                  # 如果留空，本插件会为你自动设置。
-auto_wrap = true  # 解压缩出来不止一个文件时，用一个文件夹包裹它们
-names = []        # 只有当多个任务组合时才使用此项代替命令行输入
+output = ""        # 指定压缩后的文件名或解压缩时的目标文件夹，
+                   # 如果留空，本插件会为你自动设置。
+auto_wrap = true   # 解压缩出来不止一个文件时，用一个文件夹包裹它们
+zip_overwrite = false  # 压缩后的文件是否覆盖同名文件
+names = []         # 只有当多个任务组合时才使用此项代替命令行输入
 
 使用打包压缩功能时，需要先进入一个文件夹，用相对路径选择需要打包的文件/文件夹。
 采用 lzma 压缩方法，打包压缩后的后缀名是 '.tar.xz'
 解压缩时每次只能解压缩一个文件。
+# version: 2022-01-13
 """
 
     @property  # 必须设为 @property
@@ -63,6 +66,7 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
         - self.output
         - self.mode
         - self.names
+        - self.zip_overwrite
         """
         # 要在 dry_run, exec 中确认 is_validated
         self.is_validated = True
@@ -83,9 +87,9 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
             self.mode = Mode.Unzip
         else:
             self.mode = Mode.Zip
-        print(f"mode: {self.mode.name}")
 
         self.names = names
+        self.zip_overwrite = options.get("zip_overwrite", False)
         output = options.get("output", "").strip()
         auto_wrap = options.get("auto_wrap", True)
 
@@ -110,7 +114,7 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
                 # 如果 options 里未指定 output 文件名，则自动赋予一个合理的文件名。
                 if not output:
                     if len(self.names) == 1:
-                        output = self.names[0]
+                        output = Path(self.names[0]).name
                     else:
                         output = Path.cwd().name
                 if output.endswith(suffix):
@@ -123,6 +127,7 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
 
     def dry_run(self) -> ErrMsg:
         assert self.is_validated, "在执行 dry_run 之前必须先执行 validate"
+        print(f"Mode: {self.mode.name}")
         match self.mode:
             case Mode.Unzip:
                 with tarfile.open(self.names[0]) as tar:
@@ -136,8 +141,10 @@ names = []        # 只有当多个任务组合时才使用此项代替命令行
                             return f"Already Exists: '{f}'"
                         print(f)
             case Mode.Zip:
-                if self.output.exists():
+                if self.output.exists() and not self.zip_overwrite:
                     return f"File exists: '{self.output}'"
+                if self.zip_overwrite:
+                    print(f"Overwrite: {self.zip_overwrite}")
                 print(f"Create '{self.output}'")
         return ""
 
